@@ -290,7 +290,7 @@ def recursion_handle(data: Union[List[Dict], Dict], func: Callable, children_key
             recursion_handle(i, func, children_key=children_key)
     elif isinstance(data, dict):
         if data.get(children_key):
-            data[children_key] = func(data)
+            data[children_key] = func(data.get(children_key, []) or [])
             for i in data.get(children_key):
                 recursion_handle(i, func, children_key=children_key)
 
