@@ -1,13 +1,14 @@
 import threading
 from contextlib import contextmanager
-from typing import Any, Callable, List
+from typing import Any, Callable, List, Dict, Union
 
 
 class ThreadTask:
-    def __init__(self, target, args=None, kwargs=None):
+    def __init__(self, target, args=None, kwargs=None, name: str = None):
         self.target = target
         self.args = args or []
         self.kwargs = kwargs or dict()
+        self.name = name or target.__name__
 
 
 def wrapper(_func, _args, _kwargs, _result: list = None, _lock=None, _is_throw_error=True) -> Callable:
@@ -35,14 +36,18 @@ def wrapper(_func, _args, _kwargs, _result: list = None, _lock=None, _is_throw_e
     return _thread_func
 
 
-def run_in_thread(func_list: List[ThreadTask], is_throw_error=False, is_lock=True) -> List[Any]:
+def run_in_thread(func_list: List[ThreadTask], is_throw_error=False,
+                  is_lock=True, return_type="list") -> Union[List[Any], Dict[Any, Any]]:
     results = []
     threads = []
+    name_list = []
     result_locks = []
     for obj in func_list:
         target = obj.target
         args = obj.args or []
         kwargs = obj.kwargs or dict()
+        _name = obj.name
+        name_list.append(_name)
         result = []
         if is_lock:
             lock = threading.Lock()
@@ -67,7 +72,11 @@ def run_in_thread(func_list: List[ThreadTask], is_throw_error=False, is_lock=Tru
                 final_results.append(result[0])
         else:
             final_results.append(result[0])
-    return final_results
+    if return_type == "list":
+        return final_results
+    else:
+        final_results = dict(zip(name_list, final_results))
+        return final_results
 
 
 def run_in_background(func_list: List[ThreadTask], is_throw_error=False, is_lock=False) -> bool:
